* mln/value/intsub.hh
* mln/value/intsub_1.hh
* mln/value/intsub_2.hh
* mln/value/intsub_4.hh
---
milena/ChangeLog | 9 +++++++++
milena/mln/value/intsub.hh | 6 ++----
milena/mln/value/{int_u8.hh => intsub_1.hh} | 14 +++++++-------
milena/mln/value/{int_u8.hh => intsub_2.hh} | 14 +++++++-------
milena/mln/value/{int_u8.hh => intsub_4.hh} | 14 +++++++-------
5 files changed, 32 insertions(+), 25 deletions(-)
copy milena/mln/value/{int_u8.hh => intsub_1.hh} (82%)
copy milena/mln/value/{int_u8.hh => intsub_2.hh} (82%)
copy milena/mln/value/{int_u8.hh => intsub_4.hh} (82%)
diff --git a/milena/ChangeLog b/milena/ChangeLog
index bc5e138..11c4862 100644
--- a/milena/ChangeLog
+++ b/milena/ChangeLog
@@ -1,5 +1,14 @@
2012-10-22 Guillaume Lazzara <z(a)lrde.epita.fr>
+ Add aliases for value::intsub.
+
+ * mln/value/intsub.hh
+ * mln/value/intsub_1.hh
+ * mln/value/intsub_2.hh
+ * mln/value/intsub_4.hh
+
+2012-10-22 Guillaume Lazzara <z(a)lrde.epita.fr>
+
Fix return type in functions.
* mln/fun/vv2v/max.hh,
diff --git a/milena/mln/value/intsub.hh b/milena/mln/value/intsub.hh
index 65bef77..be37291 100644
--- a/milena/mln/value/intsub.hh
+++ b/milena/mln/value/intsub.hh
@@ -216,16 +216,13 @@ namespace mln
static intsub<n> value();
};
- typedef intsub<1> intsub1;
- typedef intsub<2> intsub2;
- typedef intsub<4> intsub4;
-
} // end of namespace mln::value
extern const value::intsub<2> half;
extern const value::intsub<4> quarter;
+
# ifndef MLN_INCLUDE_ONLY
// half
@@ -521,6 +518,7 @@ namespace mln
return mean(vec[1], vec[2]);
}
+
# endif // ! MLN_INCLUDE_ONLY
} // end of namespace mln::value
diff --git a/milena/mln/value/int_u8.hh b/milena/mln/value/intsub_1.hh
similarity index 82%
copy from milena/mln/value/int_u8.hh
copy to milena/mln/value/intsub_1.hh
index 5260f42..f50ef01 100644
--- a/milena/mln/value/int_u8.hh
+++ b/milena/mln/value/intsub_1.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007, 2008, 2009 EPITA Research and Development Laboratory (LRDE)
+// Copyright (C) 2012 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -23,14 +23,14 @@
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.
-#ifndef MLN_VALUE_INT_U8_HH
-# define MLN_VALUE_INT_U8_HH
+#ifndef MLN_VALUE_INTSUB_1_HH
+# define MLN_VALUE_INTSUB_1_HH
/// \file
///
/// Define the alias value::int_u8.
# include <mln/value/int_u.hh>
namespace mln
@@ -41,7 +41,7 @@ namespace mln
/// Alias for unsigned 8-bit integers.
- typedef mln::value::int_u<8> int_u8;
+ typedef mln::value::intsub<1> intsub_1;
} // end of namespace mln::value
@@ -49,4 +49,4 @@ namespace mln
} // end of namespace mln
-#endif // ! MLN_VALUE_INT_U8_HH
+#endif // ! MLN_VALUE_INTSUB_1_HH
@@ -23,14 +23,14 @@
/// \file
///
-/// Define the alias value::int_u8.
+/// Define the alias value::intsub_1.
-# include <mln/value/int_u.hh>
+# include <mln/value/intsub.hh>
namespace mln
diff --git a/milena/mln/value/int_u8.hh b/milena/mln/value/intsub_2.hh
similarity index 82%
copy from milena/mln/value/int_u8.hh
copy to milena/mln/value/intsub_2.hh
index 5260f42..be538a3 100644
--- a/milena/mln/value/int_u8.hh
+++ b/milena/mln/value/intsub_2.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007, 2008, 2009 EPITA Research and Development Laboratory (LRDE)
+// Copyright (C) 2012 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -23,14 +23,14 @@
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.
-#ifndef MLN_VALUE_INT_U8_HH
-# define MLN_VALUE_INT_U8_HH
+#ifndef MLN_VALUE_INTSUB_2_HH
+# define MLN_VALUE_INTSUB_2_HH
/// \file
///
/// Define the alias value::int_u8.
# include <mln/value/int_u.hh>
namespace mln
@@ -41,7 +41,7 @@ namespace mln
/// Alias for unsigned 8-bit integers.
- typedef mln::value::int_u<8> int_u8;
+ typedef mln::value::intsub<2> intsub_2;
} // end of namespace mln::value
@@ -49,4 +49,4 @@ namespace mln
} // end of namespace mln
-#endif // ! MLN_VALUE_INT_U8_HH
+#endif // ! MLN_VALUE_INTSUB_2_HH
@@ -23,14 +23,14 @@
/// \file
///
-/// Define the alias value::int_u8.
+/// Define the alias value::intsub_2.
-# include <mln/value/int_u.hh>
+# include <mln/value/intsub.hh>
namespace mln
diff --git a/milena/mln/value/int_u8.hh b/milena/mln/value/intsub_4.hh
similarity index 82%
copy from milena/mln/value/int_u8.hh
copy to milena/mln/value/intsub_4.hh
index 5260f42..b2b8c94 100644
--- a/milena/mln/value/int_u8.hh
+++ b/milena/mln/value/intsub_4.hh
@@ -1,4 +1,4 @@
-// Copyright (C) 2007, 2008, 2009 EPITA Research and Development Laboratory (LRDE)
+// Copyright (C) 2012 EPITA Research and Development Laboratory (LRDE)
//
// This file is part of Olena.
//
@@ -23,14 +23,14 @@
// exception does not however invalidate any other reasons why the
// executable file might be covered by the GNU General Public License.
-#ifndef MLN_VALUE_INT_U8_HH
-# define MLN_VALUE_INT_U8_HH
+#ifndef MLN_VALUE_INTSUB_4_HH
+# define MLN_VALUE_INTSUB_4_HH
/// \file
///
/// Define the alias value::int_u8.
# include <mln/value/int_u.hh>
namespace mln
@@ -41,7 +41,7 @@ namespace mln
/// Alias for unsigned 8-bit integers.
- typedef mln::value::int_u<8> int_u8;
+ typedef mln::value::intsub<4> intsub_4;
} // end of namespace mln::value
@@ -49,4 +49,4 @@ namespace mln
} // end of namespace mln
-#endif // ! MLN_VALUE_INT_U8_HH
+#endif // ! MLN_VALUE_INTSUB_4_HH
@@ -23,14 +23,14 @@
/// \file
///
-/// Define the alias value::int_u8.
+/// Define the alias value::intsub_4.
-# include <mln/value/int_u.hh>
+# include <mln/value/intsub.hh>
namespace mln
--
1.7.2.5